//
//  YHLoginViewModel.swift
//  galaxy
//
//  Created by EDY on 2024/1/17.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHLoginViewModel: YHBaseViewModel {
    var userModel: YHUserModel?

    override init() {
        super.init()
    }
}

//接口
extension YHLoginViewModel {
    //发送验证码
    func getLoginCode(_ phone: String, callBackBlock: @escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        let params: [String : Any] = ["type": "Phone",
                                      "value": phone,
                                      "extend":"register"]
        let strUrl = "http://test-cuser.galaxy-immi.com/" + "user/verify-code"
        let _ = YHNetRequest.postRequest(url: strUrl, params: params) {[weak self] json, code in
            guard let self = self else { return }
            
            guard let model = NetBaseModel.deserialize(dict: json) else {
                let error : YHErrorModel = YHErrorModel(errorCode:YHErrorCode.dictParseError.rawValue,errorMsg: YHErrorCode.dictParseError.description())
                callBackBlock( false,error)
                return
            }
            
            //1. json字符串 转 对象
            if model.code == 200 {
                YHHUD.flash(message: model.msg)
                callBackBlock(true,nil)
            } else {
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(model.code),errorMsg: model.msg)
                callBackBlock(false,error)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
    func login(phone: String, code: String,callBackBlock: @escaping (_ success: Bool,_ error: YHErrorModel?)->()) {
        let params: [String : Any] = ["mobile": phone,
                                      "sms_code": code,
                                      "channel": "app",
                                      "client": "super_app"]
        let strUrl = "http://test.api.diymanager.galaxy-immi.com/" + "auth/login"
        let _ = YHNetRequest.postRequest(url: strUrl, params: params) {[weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            guard let model = NetBaseModel.deserialize(dict: json) else {
                let error : YHErrorModel = YHErrorModel(errorCode:YHErrorCode.dictParseError.rawValue,errorMsg: YHErrorCode.dictParseError.description())
                
                callBackBlock(false,error)
                return
            }
            let dic = model.data?.peel
            guard let resultModel = YHUserModel.deserialize(dict: dic as? [AnyHashable : Any]) else {
                let error : YHErrorModel = YHErrorModel(errorCode:-1,errorMsg: "数据解析不成功")
                callBackBlock(false,error)
                return
            }
            
            if model.code == 200 {
                if resultModel.token?.count != 0 {
                    //token 正常
                    self.userModel = resultModel
                    YHLoginManager.shared.userModel = resultModel
                    
                    //数据保存到本地
                    YHLoginManager.shared.saveLocalUserInfo()
                    
                    NotificationCenter.default.post(name: YhConstant.YhNotification.didLoginSuccessNotifiction, object: nil)
                    
                    //回调
                    callBackBlock(true,nil)
                } else {
                    let error : YHErrorModel = YHErrorModel(errorCode:-2,errorMsg: "token 不合法")
                    callBackBlock(false,error)
                }
            } else {                
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(model.code), errorMsg: model.msg)
                callBackBlock(false,error)
            }
            
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
}
